@@ -1,7 +1,7 @@
 from alira.instance import Instance
 from alira.modules import module
 
-PIPELINE_MODULE_NAME = "alira.modules.flagging"
+PIPELINE_MODULE_NAME = "flagging"
 
 
 class Flagging(module.Module):
@@ -40,9 +40,9 @@ class CostSensitiveFlagging(module.Module):
     review costs used by this module by specifying a value for the `fp_cost`,
     `fn_cost`, and `human_review_cost` attributes::
 
-        instance.metadata['alira.modules.flagging']['fp_cost'] = 100
-        instance.metadata['alira.modules.flagging']['fn_cost'] = 300
-        instance.metadata['alira.modules.flagging']['human_review_cost'] = 10
+        instance.metadata['flagging']['fp_cost'] = 100
+        instance.metadata['flagging']['fn_cost'] = 300
+        instance.metadata['flagging']['human_review_cost'] = 10
 
     The costs specified as part of the instance will always be used over
     the costs specified for this module.
